@@ -1,3 +1,4 @@
+from ConfigParser import NoOptionError
 from functools import partial
 
 from suds.client import Client
@@ -7,7 +8,10 @@ from .config import ebaysuds_config
 from .transport import WellBehavedHttpTransport
 
 
-WSDL_URL = "http://developer.ebay.com/webservices/latest/ebaySvc.wsdl"
+try:
+    WSDL_URL = ebaysuds_config.has_option('wsdl', 'url')
+except NoOptionError:
+    WSDL_URL = "http://developer.ebay.com/webservices/latest/ebaySvc.wsdl"
 GATEWAY_URI_QUERYSTRING = "?callname=%(call_name)s&siteid=%(site_id)s&appid=%(app_id)s&version=%(version)s&routing=default"
 
 
